@@ -12,5 +12,8 @@ class CoveragePlugin(Plugin):
     self.coverage.stop()
 
   def finish_running_tests(self, test_driver):
-    self.coverage.html_report(directory = 'covhtml')
+    try:
+      self.coverage.html_report(directory = 'covhtml')
+    except:
+      pass #HACK
 
